@@ -118,3 +118,15 @@
 #endif
 
 #define MAX_GATHERER_BYTES	100000
+
+#define ENTROPY_NEEDED		20
+
+/*
+ * Define the minimum of entropy we want to have in the pool on a regular
+ * basis. If we come below this threshold, the gatherer processes are fired
+ * up continously until we come back over the threshold.
+ */
+#ifndef THRESHOLD
+#define THRESHOLD		4
+#endif
+#define ENTROPY_THRESHOLD	(ENTROPY_NEEDED * 8 * THRESHOLD)
