@@ -15,10 +15,9 @@
 #include <sys/wait.h>
 #include <netinet/in.h>
 
-#include "config.h"
 #include "prngd.h"
 
-int randsavefd;
+int randsavefd = -1;
 int debug = 0;
 
 int devnull = -1;
@@ -113,8 +112,10 @@ static void write_seedfile(void)
 
 void close_seedfile(void)
 {
-  write_seedfile();
-  close(randsavefd);
+  if (randsavefd >= 0) {
+    write_seedfile();
+    close(randsavefd);
+  }
 }
 
 
@@ -165,7 +166,7 @@ static void killpeer(int service_socket)
 static void usage(const char *progname)
 {
   fprintf(stderr,
-	  "Usage: %s [options] /path/to/socket1 [/path/to/socket2 ...]\nOptions:\n\t-d: debugging on\n\t-c cmdpath: use cmdpath for entropy commands [%s]\n\t-s seedpath: use seedpath as seedfile [%s]\n\t--kill: kill daemon on other side\n",
+	  "Usage: %s [options] /path/to/socket1 [/path/to/socket2 ...]\nOptions:\n\t-d/--debug: debugging on\n\t-c/--cmdfile cmdpath: use cmdpath for entropy commands [%s]\n\t-s/--seedfile seedpath: use seedpath as seedfile [%s]\n\t-n/--no-seedfile: no seedfile, keep pool in memory only\n\t-k/--kill: kill daemon on other side\n",
 	  progname, CONFIGFILE, RANDSAVENAME);
 }
 
@@ -193,13 +194,17 @@ int main(int argc, char *argv[])
   argp = 1;
   while (argp < argc)
   {
-    if (!strcmp(argv[argp], "-d"))
+    if (!strcmp(argv[argp], "-d") || !strcmp(argv[argp], "--debug"))
       debug = 1;
-    else if (!strcmp(argv[argp], "-c") && (argp + 1 < argc))
+    else if ((!strcmp(argv[argp], "-c") || !strcmp(argv[argp], "--cmdfile"))
+	     && (argp + 1 < argc))
       cmdpath = argv[++argp];
-    else if (!strcmp(argv[argp], "-s") && (argp + 1 < argc))
+    else if ((!strcmp(argv[argp], "-s") || !strcmp(argv[argp], "--seedfile"))
+	     && (argp + 1 < argc))
       seedpath = argv[++argp];
-    else if (!strcmp(argv[argp], "--kill"))
+    else if (!strcmp(argv[argp], "-n") || !strcmp(argv[argp], "--no-seedfile"))
+      seedpath = NULL;
+    else if (!strcmp(argv[argp], "-k") || !strcmp(argv[argp], "--kill"))
       killmode = 1;
     else if (argv[argp][0] != '-') {
       if (numsock == 0)
@@ -245,9 +250,10 @@ int main(int argc, char *argv[])
   }
 
   /*
-   * Start by reading back the seed saved from former runs. 
+   * Start by reading back the seed saved from former runs, if usage of a
+   * seedfile is wanted. 
    */
-  if (!killmode)
+  if (!killmode && seedpath)
     open_seedfile(seedpath);
 
   if (!(service_socket = malloc(numsock * sizeof(int)))) {
