@@ -2,10 +2,13 @@
 #include <sys/un.h>
 #include <sys/time.h>
 #include <sys/times.h>
+#include <unistd.h>
+
+#include "config.h"
+
 #ifdef HAVE_GETRUSAGE
 #include <sys/resource.h>
 #endif
-
 #ifndef HAVE_DAEMON
 int daemon(int nochdir, int noclose);
 #endif
