@@ -1,11 +1,6 @@
-#include <stdio.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-
 #include <openssl/rand.h>
 #include <openssl/sha.h>
 
-#include "config.h"
 #include "prngd.h"
 
 static unsigned char obfuscator = 0;
