@@ -5,10 +5,8 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/types.h>
-#include <sys/socket.h>
 #include <sys/stat.h>
 
-#include "config.h"
 #include "prngd.h"
 
 static const char *statfiles[] = {
