@@ -171,7 +171,7 @@ void main_loop(int *service_socket, int numsock, struct sockaddr_un sockun,
      * If we just entered the loop and gather for the first time, we
      * don't want to wait.
      */
-    if (first_gather) {
+    if (first_gather || (rand_pool() < (ENTROPY_THRESHOLD))) {
       timeout.tv_sec = 0;
       timeout.tv_usec = 10;
     }
@@ -248,7 +248,8 @@ void main_loop(int *service_socket, int numsock, struct sockaddr_un sockun,
      * Call a gatherer, if it is time to do so. When starting up, call
      * all gatherers once to obtain initial seeding.
      */
-    if (((time(0) >= last_seed_ext + seed_ext_interval) || first_gather) &&
+    if (((time(0) >= last_seed_ext + seed_ext_interval) || first_gather ||
+	(rand_pool() < (ENTROPY_THRESHOLD))) &&
 	(gather_fd == -1))
     {
       last_seed_ext = time(0);
@@ -318,7 +319,13 @@ void main_loop(int *service_socket, int numsock, struct sockaddr_un sockun,
 	  close(gather_fd);
         }
 	gather_start = time(NULL);
-	fprintf(stderr, "Spawned gatherer\n");
+	fprintf(stderr, "Spawned gatherer: %s (%s",
+		entropy_source[gatherer_entry].path,
+		entropy_source[gatherer_entry].args[0]);
+	for (i = 1; i < 5; i++)
+	  if (entropy_source[gatherer_entry].args[i])
+	    fprintf(stderr, " %s", entropy_source[gatherer_entry].args[i]);
+	fprintf(stderr, ")\n");
       }
       continue;
 
